@@ -20,14 +20,14 @@ use Clone qw(clone);
 use Data::Dumper;
 use JSON;
 use URI::Template;
+use RDF::LDF::Error;
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 {
-	my $ua	= RDF::Trine->default_useragent;
-	$ua->agent("RDF:::LDF/$RDF::LDF::VERSION " . $ua->_agent);
+   my $ua   = RDF::Trine->default_useragent;
+   $ua->agent("RDF:::LDF/$RDF::LDF::VERSION " . $ua->_agent);
 }
 
-
 has url => (
     is => 'ro' ,
     required => 1
@@ -77,7 +77,7 @@ sub get_pattern {
     my ($self,$bgp,$context,%args) = @_;
 
     unless (defined $bgp) {
-        throw RDF::Trine::Error::MethodInvocationError -text => "can't execute get_pattern for an empty pattern";
+       RDF::LDF::Error->throw(text => "can't execute get_pattern for an empty pattern");
     }
 
     my (@triples)   = ($bgp->isa('RDF::Trine::Statement') or $bgp->isa('RDF::Query::Algebra::Filter'))
@@ -85,7 +85,7 @@ sub get_pattern {
                     : $bgp->triples;
 
     unless (@triples) {
-        throw RDF::Trine::Error::MethodInvocationError -text => "can't execute get_pattern for an empty pattern";
+        RDF::LDF::Error->throw(text => "can't execute get_pattern for an empty pattern");
     }
 
     my @vars = $bgp->referenced_variables;
@@ -274,7 +274,7 @@ sub _find_best_pattern {
     return ($best_pattern, \@rest_triples);
 }
 
-# Find the total number of trilpes available for a pattern
+# Find the total number of triples available for a pattern
 #
 # Usage:
 #
@@ -314,10 +314,10 @@ sub _node_as_string {
 # For an BGP triple create a fragment pattern
 sub _parse_triple_pattern {
     my ($self,$triple) = @_;
-    my $subject        = $self->_node_as_string($triple->subject);
-    my $predicate    = $self->_node_as_string($triple->predicate);
-    my $object        = $self->_node_as_string($triple->object);
-    my $hash        = {
+    my $subject   = $self->_node_as_string($triple->subject);
+    my $predicate = $self->_node_as_string($triple->predicate);
+    my $object    = $self->_node_as_string($triple->object);
+    my $hash      = {
         subject   => $subject ,
         predicate => $predicate,
         object    => $object
@@ -325,7 +325,7 @@ sub _parse_triple_pattern {
     return $hash;
 }
 
-# Dynamic find out which tripple patterns need to be used to query the fragment server
+# Dynamic find out which triple patterns need to be used to query the fragment server
 # Returns a hash:
 # {
 #   rdf_subject   => <name_of_subject_variable> ,
@@ -392,9 +392,9 @@ sub get_statements {
     return undef unless defined $pattern;
     
     my %params;
-    $params{ $pattern->{rdf_subject} }        = $subject if is_string($subject);
-    $params{ $pattern->{rdf_predicate} }    = $predicate if is_string($predicate);
-    $params{ $pattern->{rdf_object} }        = $object if is_string($object);
+    $params{ $pattern->{rdf_subject} }   = $subject if is_string($subject);
+    $params{ $pattern->{rdf_predicate} } = $predicate if is_string($predicate);
+    $params{ $pattern->{rdf_object} }    = $object if is_string($object);
     
     my $template    = URI::Template->new($pattern->{void_uriLookupEndpoint});
     my $url            = $template->process(%params)->as_string;
@@ -506,7 +506,7 @@ sub _model_metadata {
         'http://www.w3.org/ns/hydra/core#property' ,
         'http://www.w3.org/ns/hydra/core#mapping'  ,
         'http://www.w3.org/ns/hydra/core#template' ,
-        'http://www.w3.org/ns/hydra/core#membe'    ,
+        'http://www.w3.org/ns/hydra/core#member'   ,
     ) {
         $self->_build_metadata($model, {
             predicate => RDF::Trine::Node::Resource->new($predicate)
